from itertools import zip_longest
import requests 
from requests import Session 
import re 
from  .file_handle import *  



FILE_NAME = 'ot_sites - Copy.csv'
file = file_handle(FILE_NAME)
logger = [] 


class ot:
    def __init__(self,token,base_url):   
        self.url= base_url 
        # 'https://app-fr.onetrust.com'

        self.session=Session()
        self.session.headers.update( {
                    "Content-Type": "application/json",
                    "Authorization": 'Bearer' + token
                     })     

        

    def get_scan_sites(self,col_num_site,col_num_org,number_of_pages):
        site_list = file.read_by_col(col_num_site)
        org_list = file.read_by_col(col_num_org)
        url= self.url + '/api/cookiemanager/v2/websites'
        site_org_map= (list((zip_longest(site_list, org_list))))
        for index,site in enumerate (site_org_map):
            site_to_scan=(site_org_map[index][0]).split(' ')
            org_to_scan = (site_org_map[index][1])
            payload = {
                'domainsList': site_to_scan,
                "externalOrgId": org_to_scan,
                "includedQueryParams": "string",
                "keepExistingData": True,
                "numberOfPages": number_of_pages,
                "scanRequired": True,
            }
            r=self.session.post(url,json=payload)
            if (r.status_code ==200) :
                print ('Success : ', r.status_code)
                responses = r.json()
                for response in responses:
                    print(response['message'])
                    logger.append(response['message'])


            else:
                print (f'Error: {r.status_code} API key has probably expired or request is incorrrect. Create a new API key on the OT interface and try again') 
                exit()  
              
        file.write_to_column ('LOG',logger,file.get_file_headers())  

    def publish_script(self,col_num,script_type): 
        sites = file.read_by_col(col_num)  
        url= self.url + '/api/cookiemanager/v2/websites/publish'    
        payload={
        "languageDetectionEnabled": True,
        "languageDetectionHtml": True
        
            }
        for site in sites:
            r=self.session.request("PUT", url, json=payload,params={"website":site,"scriptType":script_type})
            if (r.status_code ==200) :
                print ('Success : ', r.status_code)
                logger.append(r.json()['responseMsg'])
                
            else:
                print (f'Error: {r.status_code} API key has probably expired or request is incorrrect. Create a new API key on the OT interface and try again')  
                exit()   
        file.write_to_column ('LOG',logger,file.get_file_headers())


    def get_api_key_retrieve(self,col_num,script_type,write_to_file):
        site_list = file.read_by_col(col_num)
        key_list=list ()
        url= self.url + '/api/cookiemanager/v2/websites/scripts'
        for site in site_list:
            query_params={"website":site,"scriptType":script_type}
            r=self.session.get(url,params=query_params)
            if (r.status_code ==200) :
                print ('Success : ', r.status_code)
                data = r.text
                data_line= data.split("\n")
                for line in data_line:
                    results=re.findall('data-domain-script="(.*-{0,5})"',line)
                    for result in results:
                        if (len(result) >0):
                            key_list.append(result)
            else:
                print (f'Error: {r.status_code} API key has probably expired or request is incorrrect. Create a new API key on the OT interface and try again') 
                exit() 
        if write_to_file == 'yes': 
            print (f'writing to file:{FILE_NAME}')  
            file.write_to_column('API-Key',key_list,file.get_file_headers())         
            # return key_list
        else:
            print('writing to console ...')
            print (key_list)


    def get_site_attributes (self,extract_attr,write_to_file,search_domain_list):
        for domain in search_domain_list: 
            site_list=[]
            attr_dict = {}
            url= self.url + '/api/cookiemanager/v2/websites'
            query_params = {'searchStr': domain}
            r=self.session.get(url,params=query_params)
            if (r.status_code ==200) :
                if not r.json()['content']:
                    print ('No content to be retrieved for {}'.format(domain))
                    continue
                print ('Success : ', r.status_code)
                sites_scanned= r.json()['content']
                for sites in sites_scanned:
                    for attr in extract_attr:
                        try:
                            attr_dict[attr]=sites[attr]
                        except:
                            print ('{} does not exist'.format(attr))    
                            continue
                    site_list.append (attr_dict.copy())
                if write_to_file == 'yes':
                    print (f'writing to file:{FILE_NAME}')    
                    file.append_dict(site_list,extract_attr)
                
                else:
                    print('writing to console ...')
                    print (site_list)
            else:
                print (f'Error: {r.status_code} API key has probably expired or request is incorrrect. Create a new API key on the OT interface and try again') 
                exit()   
# print (f' This module is {__name__}')            


from csv import reader
import os
import csv 
import pandas as pd 


class file_handle:
    def __init__(self,file_name):
        self.file_name=file_name

    def append_dict(self,site_info,header_list):
        if isinstance(site_info,dict):
            writer_header = False
            if not os.path.isfile(self.file_name):
                writer_header = True
            with open (self.file_name,mode='a',newline='') as f :
                fieldnames = header_list
                writer = csv.DictWriter( f,fieldnames=fieldnames)
                if writer_header == True:
                    writer.writeheader()  
                writer.writerow(site_info)    
        else:
            for site_dict in site_info:
                self.append_dict(site_dict,header_list)

    def read_by_col(self,col_num) :
        result_list=[]
        with open (self.file_name,mode='r',newline='') as f :
            fhandle=reader(f)
            fhandle=list(fhandle)
            fhandle = fhandle[1:]
            try:
                for col in fhandle:
                    result_list.append(col[col_num-1])
            except :
                print ('Error ! : Remove unused rows from the CSV file')
                exit()
            return result_list


    def get_file_headers(self):
        header_list = []
        with open (self.file_name,mode='r',newline='') as f :
            fhandle=reader(f)
            fhandle=list(fhandle)
            fhandle = fhandle[0]
            for row in fhandle:
                header_list.append(row)
            return header_list



    def write_to_column(self, header_name, write_list,header_list):
        data_dict= {}
        key_list =[] 
        for index, header in enumerate (header_list):
            data_dict[header] = self.read_by_col(index+1)
        for key in write_list:
            key_list.append(key)
        data_dict[header_name] = key_list
        try:
            data_frame = pd.DataFrame(data_dict)
            data_frame.to_csv(self.file_name, mode='w',index=False)
        except:
            print ('nothing to log ') 
 
# print (f' This module is {__name__}')


import os
from setuptools import setup, find_packages
from pathlib import Path
from setuptools import setup
this_directory = Path(__file__).parent



VERSION = '0.0.12'
DESCRIPTION = 'One Trust API Library 55'
long_description = (this_directory / "README.md").read_text()
with open('requirements.txt') as f:
    required = f.read().splitlines()
# Setting up
print(required)
setup(
    name="one_trust_55",
    version=VERSION,
    author="Rohit Lobo",
    author_email="rohit.lobo@fifty-five.com",
    # readme = "README.md",
    url="https://gitlab.55labs.com/rohit.lobo/one_trust_api.git",
    description= DESCRIPTION,
    py_modules=["main"],
    long_description =long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    # install_requires=['pandas == 1.4.4','requests'],
    install_requires=required,
    keywords=['python', 'one trust', '55']
)
